@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2017-08-12'; # DATE
-our $VERSION = '0.420'; # VERSION
+our $DATE = '2018-01-17'; # DATE
+our $VERSION = '0.421'; # VERSION
 
 use 5.010001;
 use strict;
@@ -55,6 +55,10 @@ has validate_args => (is=>'rw');
 has pack_deps => (is=>'rw');
 has read_config => (is=>'rw');
 has read_env => (is=>'rw');
+has copt_version_enable => (is=>'rw');
+has copt_version_getopt => (is=>'rw');
+has copt_help_enable => (is=>'rw');
+has copt_help_getopt => (is=>'rw');
 
 has inline_generate_completer => (is=>'rw', default=>1);
 
@@ -171,6 +175,10 @@ sub munge_files {
             pod => 0, # will be generated by PWP:Rinci
             (read_config => $self->read_config) x !!defined($self->read_config),
             (read_env => $self->read_env) x !!defined($self->read_env),
+            (copt_help_enable => $self->copt_help_enable) x !!defined($self->copt_help_enable),
+            (copt_help_getopt => $self->copt_help_getopt) x !!defined($self->copt_help_getopt),
+            (copt_version_enable => $self->copt_version_enable) x !!defined($self->copt_version_enable),
+            (copt_version_getopt => $self->copt_version_getopt) x !!defined($self->copt_version_getopt),
         );
         #use DD; dd \%gen_args;
         $res = gen_pericmd_script(%gen_args);
@@ -262,7 +270,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.420 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-08-12.
+This document describes version 0.421 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2018-01-17.
 
 =head1 SYNOPSIS
 
@@ -494,7 +502,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
